@@ -136,25 +136,50 @@ This is used by the commands `doric-themes-toggle',
            (doric-themes--list-known-themes))))
 
 (defun doric-themes--annotate-theme (theme)
-  "Return completion annotation for THEME."
+  "Return description of THEME ."
   (when-let* ((symbol (intern-soft theme))
-              (doc-string (get symbol 'theme-documentation)))
-    (format " -- %s" (propertize (car (split-string doc-string "\\.")) 'face 'completions-annotations))))
-
-(defun doric-themes--completion-table (category candidates)
-  "Pass appropriate metadata CATEGORY to completion CANDIDATES."
-  (lambda (string pred action)
-    (if (eq action 'metadata)
-        `(metadata (category . ,category))
-      (complete-with-action action candidates string pred))))
-
-(defun doric-themes--completion-table-candidates ()
-  "Render `doric-themes--list-known-themes' as completion with theme category."
-  (doric-themes--completion-table 'theme (doric-themes--list-known-themes)))
+              (properties (get symbol 'theme-properties))
+              (doc-string (or (get symbol 'theme-documentation)
+                              (plist-get properties :doric-documentation))))
+    (format " %s"
+            (propertize (concat "-- " (car (split-string doc-string "\\.")))
+                        'face 'completions-annotations))))
 
 (defvar doric-themes-select-theme-history nil
   "Minibuffer history of `doric-themes-select-prompt'.")
 
+(defun doric-themes--group-themes (theme transform)
+  "Group THEME by its background for minibuffer completion.
+If TRANSFORM is non-nil, return THEME as-is."
+  (let ((symbol (intern-soft theme)))
+    (cond
+     (transform
+      theme)
+     ((eq symbol (doric-themes--current-theme))
+      "Current")
+     ((when-let* ((properties (get symbol 'theme-properties))
+                  (background (plist-get properties :background-mode)))
+        (capitalize (format "%s" background)))))))
+
+(defun doric-themes--display-sort (themes)
+  "Put the current theme before other THEMES for minibuffer completion."
+  (let* ((current (doric-themes--current-theme))
+         (current-theme-p (lambda (theme) (eq (intern-soft theme) current))))
+    (nconc
+     (seq-filter current-theme-p themes)
+     (seq-remove current-theme-p themes))))
+
+(defun doric-themes--completion-table (themes)
+  "Pass appropriate metadata to THEMES for minibuffer completion."
+  (lambda (string pred action)
+    (if (eq action 'metadata)
+        (list 'metadata
+              (cons 'category 'theme)
+              (cons 'annotation-function #'doric-themes--annotate-theme)
+              (cons 'group-function #'doric-themes--group-themes)
+              (cons 'display-sort-function #'doric-themes--display-sort))
+      (complete-with-action action themes string pred))))
+
 (defun doric-themes-select-prompt (&optional prompt)
   "Minibuffer prompt to select a Doric theme.
 With optional PROMPT string, use it.  Else use a generic prompt."
@@ -162,7 +187,7 @@ With optional PROMPT string, use it.  Else use a generic prompt."
     (intern
      (completing-read
       (or prompt "Select Doric theme: ")
-      (doric-themes--completion-table-candidates)
+      (doric-themes--completion-table (doric-themes--list-known-themes))
       nil t nil 'doric-themes-select-theme-history))))
 
 (defun doric-themes-load-theme (theme)
@@ -622,6 +647,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     proced-interruptible-sleep-status-code
     proced-mem
     shadow
+    so-long-mode-line-inactive
     tab-bar-tab-group-inactive
     tab-bar-tab-ungrouped
     transient-inactive-argument
@@ -785,13 +811,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     proced-memory-medium-usage
     proced-user
     sgml-namespace
-    shr-abbreviation
-    shr-sliced-image
-    shr-strike-through
-    shr-sup
-    shr-text
     shortdoc-section
-    so-long-mode-line-inactive
     speedbar-file-face
     tabulated-list-fake-header
     vc-dir-directory
@@ -1286,7 +1306,15 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     dired-broken-symlink
     error
     ert-test-result-unexpected
-    flymake-error-fringe))
+    flymake-error-fringe
+    whitespace-line
+    whitespace-space-after-tab
+    whitespace-space-before-tab))
+
+(defconst doric-themes-error-background-faces
+  '(magit-diff-whitespace-warning
+    trailing-whitespace
+    whitespace-trailing))
 
 (defconst doric-themes-warning-foreground-only-faces
   '(TeX-error-description-warning
@@ -1392,7 +1420,7 @@ default to a generic text that mentions the BACKGROUND-MODE."
                (list `(custom-declare-theme
                        ',name 'doric-themes
                        ,(or description (format "Minimalist %s theme." background-mode))
-                       (list :kind 'color-scheme :background-mode ',background-mode :family 'doric))))
+                       (list :kind 'color-scheme :background-mode ',background-mode :family 'doric :doric-documentation ,description))))
            (let ,palette
              (custom-theme-set-faces
               ',name
@@ -1486,6 +1514,7 @@ default to a generic text that mentions the BACKGROUND-MODE."
               ,@(doric-themes-prepare-faces doric-themes-error-underline-faces :underline '(list :style 'wave :color fg-red))
               ,@(doric-themes-prepare-faces doric-themes-warning-underline-faces :underline '(list :style 'wave :color fg-yellow))
               ,@(doric-themes-prepare-faces doric-themes-success-underline-faces :underline '(list :style 'wave :color fg-cyan))
+              ,@(doric-themes-prepare-faces doric-themes-error-background-faces :background '(doric-themes-adjust-value bg-red 30))
 
               ,@(doric-themes-prepare-faces doric-themes-bold-faces :inherit ''bold :foreground 'fg-shadow-intense)
               ,@(doric-themes-prepare-faces doric-themes-bold-intense-faces :inherit ''bold :foreground 'fg-main)
@@ -1732,16 +1761,13 @@ default to a generic text that mentions the BACKGROUND-MODE."
 
               '(which-key-key-face ((t :inherit (fixed-pitch bold-italic))))
 
-              `(whitespace-big-indent ((t :foreground ,bg-shadow-intense)))
+              `(whitespace-big-indent ((t :background ,bg-shadow-intense)))
               `(whitespace-empty ((t :foreground ,bg-shadow-intense)))
               `(whitespace-hspace ((t :foreground ,bg-shadow-intense)))
               `(whitespace-indentation ((t :foreground ,bg-shadow-intense)))
-              `(whitespace-line ((t :foreground ,bg-shadow-intense)))
               `(whitespace-missing-newline-at-eof ((t :foreground ,bg-shadow-intense)))
               `(whitespace-newline ((t :foreground ,bg-shadow-intense)))
               `(whitespace-space ((t :foreground ,bg-shadow-intense)))
-
-              `(whitespace-space-before-tab ((t :foreground ,bg-shadow-intense)))
               `(whitespace-tab ((t :foreground ,bg-shadow-intense)))))
            (custom-theme-set-variables
             ',name
